@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class ObjectModeOperator:
     def poll(self, context):
@@ -77,6 +75,24 @@ class QuickLiquid(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -137,6 +153,12 @@ class QuickLiquid(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -232,6 +254,24 @@ class QuickExplode(ObjectModeOperator, bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -304,6 +344,12 @@ class QuickExplode(ObjectModeOperator, bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -399,6 +445,24 @@ class QuickFur(ObjectModeOperator, bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -465,6 +529,12 @@ class QuickFur(ObjectModeOperator, bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -560,6 +630,24 @@ class QuickSmoke(ObjectModeOperator, bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -626,6 +714,12 @@ class QuickSmoke(ObjectModeOperator, bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
