@@ -2,8 +2,6 @@ import sys
 import typing
 import bmesh.types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def edge_rotate(edge: 'bmesh.types.BMEdge',
                 ccw: bool = False) -> 'bmesh.types.BMEdge':
@@ -21,7 +19,7 @@ def edge_rotate(edge: 'bmesh.types.BMEdge',
 
 
 def edge_split(edge: 'bmesh.types.BMEdge', vert: 'bmesh.types.BMVert',
-               fac: float) -> typing.Tuple:
+               fac: float) -> tuple:
     ''' Split an edge, return the newly created data.
 
     :param edge: The edge to split.
@@ -30,7 +28,7 @@ def edge_split(edge: 'bmesh.types.BMEdge', vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param fac: The point on the edge where the new vert will be created [0 - 1].
     :type fac: float
-    :rtype: typing.Tuple
+    :rtype: tuple
     :return: The newly created (edge, vert) pair.
     '''
 
@@ -67,8 +65,7 @@ def face_split(face: 'bmesh.types.BMFace',
                vert_b: 'bmesh.types.BMVert',
                coords: typing.List[float] = (),
                use_exist: bool = True,
-               example: 'bmesh.types.BMEdge' = None
-               ) -> typing.Tuple['bmesh.types.BMFace', 'bmesh.types.BMLoop']:
+               example: 'bmesh.types.BMEdge' = None) -> 'bmesh.types.BMLoop':
     ''' Face split with optional intermediate points.
 
     :param face: The face to cut.
@@ -83,7 +80,7 @@ def face_split(face: 'bmesh.types.BMFace',
     :type use_exist: bool
     :param example: Newly created edge will copy settings from this one.
     :type example: 'bmesh.types.BMEdge'
-    :rtype: typing.Tuple['bmesh.types.BMFace', 'bmesh.types.BMLoop']
+    :rtype: 'bmesh.types.BMLoop'
     :return: The newly created face or None on failure.
     '''
 
@@ -91,7 +88,7 @@ def face_split(face: 'bmesh.types.BMFace',
 
 
 def face_split_edgenet(face: 'bmesh.types.BMFace',
-                       edgenet: 'bmesh.types.BMEdge') -> typing.Tuple:
+                       edgenet: 'bmesh.types.BMEdge') -> 'bmesh.types.BMFace':
     ''' Splits a face into any number of regions defined by an edgenet.
 
     :param face: The face to split. The face to split.
@@ -100,7 +97,7 @@ def face_split_edgenet(face: 'bmesh.types.BMFace',
     :type face: 'bmesh.types.BMFace'
     :param edgenet: Sequence of edges.
     :type edgenet: 'bmesh.types.BMEdge'
-    :rtype: typing.Tuple
+    :rtype: 'bmesh.types.BMFace'
     :return: The newly created faces.
     '''
 
@@ -150,7 +147,7 @@ def vert_collapse_edge(vert: 'bmesh.types.BMVert',
 
 
 def vert_collapse_faces(vert: 'bmesh.types.BMVert', edge: 'bmesh.types.BMEdge',
-                        fac: float, join_faces) -> 'bmesh.types.BMEdge':
+                        fac: float, join_faces: bool) -> 'bmesh.types.BMEdge':
     ''' Collapses a vertex that has only two manifold edges onto a vertex it shares an edge with.
 
     :param vert: The vert that will be collapsed.
@@ -159,6 +156,8 @@ def vert_collapse_faces(vert: 'bmesh.types.BMVert', edge: 'bmesh.types.BMEdge',
     :type edge: 'bmesh.types.BMEdge'
     :param fac: The factor to use when merging customdata [0 - 1].
     :type fac: float
+    :param join_faces: When true the faces around the vertex will be joined otherwise collapse the vertex by merging the 2 edges this vertex connects to into one.
+    :type join_faces: bool
     :rtype: 'bmesh.types.BMEdge'
     :return: The resulting edge from the collapse operation.
     '''
@@ -179,14 +178,14 @@ def vert_dissolve(vert: 'bmesh.types.BMVert') -> bool:
 
 
 def vert_separate(vert: 'bmesh.types.BMVert',
-                  edges: 'bmesh.types.BMEdge') -> typing.Tuple:
+                  edges: 'bmesh.types.BMEdge') -> 'bmesh.types.BMVert':
     ''' Separate this vertex at every edge.
 
     :param vert: The vert to be separated.
     :type vert: 'bmesh.types.BMVert'
     :param edges: The edges to separated.
     :type edges: 'bmesh.types.BMEdge'
-    :rtype: typing.Tuple
+    :rtype: 'bmesh.types.BMVert'
     :return: The newly separated verts (including the vertex passed).
     '''
 
