@@ -1,7 +1,5 @@
 import sys
 import typing
-
-GenericType = typing.TypeVar("GenericType")
 depsgraph_update_post = None
 ''' on depsgraph update (post)
 '''
@@ -93,3 +91,7 @@ undo_pre = None
 version_update = None
 ''' on ending the versioning code
 '''
+
+xr_session_start_pre = None
+''' on starting an xr session (before)
+'''
