@@ -1,44 +1,24 @@
 import sys
 import typing
-import bpy.types
-
-GenericType = typing.TypeVar("GenericType")
 
 
-def clear_filter(override_context: typing.
-                 Union[typing.Dict, 'bpy.types.Context'] = None,
-                 execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+def clear_filter():
     ''' Clear the search filter
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
 
 
-def context_menu(override_context: typing.
-                 Union[typing.Dict, 'bpy.types.Context'] = None,
-                 execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+def context_menu():
     ''' Display properties editor context_menu
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
 
 
-def directory_browse(override_context: typing.
-                     Union[typing.Dict, 'bpy.types.Context'] = None,
-                     execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
-                     *,
-                     directory: str = "",
+def directory_browse(directory: str = "",
                      hide_props_region: bool = True,
                      filter_blender: bool = False,
                      filter_backup: bool = False,
@@ -53,6 +33,7 @@ def directory_browse(override_context: typing.
                      filter_collada: bool = False,
                      filter_alembic: bool = False,
                      filter_usd: bool = False,
+                     filter_obj: bool = False,
                      filter_volume: bool = False,
                      filter_folder: bool = False,
                      filter_blenlib: bool = False,
@@ -62,9 +43,6 @@ def directory_browse(override_context: typing.
                      sort_method: typing.Union[str, int] = ''):
     ''' Open a directory browser, hold Shift to open the file, Alt to browse containing directory
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param directory: Directory, Directory of the file
     :type directory: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -95,6 +73,8 @@ def directory_browse(override_context: typing.
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
@@ -114,12 +94,7 @@ def directory_browse(override_context: typing.
     pass
 
 
-def file_browse(override_context: typing.
-                Union[typing.Dict, 'bpy.types.Context'] = None,
-                execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
-                *,
-                filepath: str = "",
+def file_browse(filepath: str = "",
                 hide_props_region: bool = True,
                 filter_blender: bool = False,
                 filter_backup: bool = False,
@@ -134,6 +109,7 @@ def file_browse(override_context: typing.
                 filter_collada: bool = False,
                 filter_alembic: bool = False,
                 filter_usd: bool = False,
+                filter_obj: bool = False,
                 filter_volume: bool = False,
                 filter_folder: bool = False,
                 filter_blenlib: bool = False,
@@ -143,9 +119,6 @@ def file_browse(override_context: typing.
                 sort_method: typing.Union[str, int] = ''):
     ''' Open a file browser, hold Shift to open the file, Alt to browse containing directory
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -176,6 +149,8 @@ def file_browse(override_context: typing.
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
@@ -195,29 +170,17 @@ def file_browse(override_context: typing.
     pass
 
 
-def start_filter(override_context: typing.
-                 Union[typing.Dict, 'bpy.types.Context'] = None,
-                 execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+def start_filter():
     ''' Start entering filter text
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
 
 
-def toggle_pin(override_context: typing.
-               Union[typing.Dict, 'bpy.types.Context'] = None,
-               execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
+def toggle_pin():
     ''' Keep the current data-block displayed
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
