@@ -28,9 +28,9 @@ def ply(filepath: str = "",
     :type use_selection: bool
     :param use_mesh_modifiers: Apply Modifiers, Apply Modifiers to the exported mesh
     :type use_mesh_modifiers: bool
-    :param use_normals: Normals, Export Normals for smooth and hard shaded faces (hard shaded faces will be exported as individual faces)
+    :param use_normals: Normals, Export vertex normals
     :type use_normals: bool
-    :param use_uv_coords: UVs, Export the active UV layer
+    :param use_uv_coords: UVs, Export the active UV layer (will split edges by seams)
     :type use_uv_coords: bool
     :param use_colors: Vertex Colors, Export the active vertex color layer
     :type use_colors: bool
