@@ -93,12 +93,13 @@ def open(filepath: str = "",
          filter_collada: bool = False,
          filter_alembic: bool = False,
          filter_usd: bool = False,
+         filter_obj: bool = False,
          filter_volume: bool = False,
          filter_folder: bool = True,
          filter_blenlib: bool = False,
          filemode: int = 9,
          relative_path: bool = True,
-         display_type: typing.Union[str, int] = 'DEFAULT',
+         display_type: typing.Union[str, int] = 'THUMBNAIL',
          sort_method: typing.Union[str, int] = ''):
     ''' Load a new font from a file
 
@@ -132,6 +133,8 @@ def open(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
@@ -232,6 +235,7 @@ def text_paste_from_file(filepath: str = "",
                          filter_collada: bool = False,
                          filter_alembic: bool = False,
                          filter_usd: bool = False,
+                         filter_obj: bool = False,
                          filter_volume: bool = False,
                          filter_folder: bool = True,
                          filter_blenlib: bool = False,
@@ -270,6 +274,8 @@ def text_paste_from_file(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
