@@ -645,9 +645,11 @@ def layer_mask_remove():
     pass
 
 
-def layer_merge():
-    ''' Merge the current layer with the layer below
+def layer_merge(mode: typing.Union[str, int] = 'ACTIVE'):
+    ''' Combine Layers
 
+    :param mode: Mode * ACTIVE Active -- Combine active layer into the layer below. * ALL All -- Combine all layers into the active layer.
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -821,7 +823,7 @@ def paste(type: typing.Union[str, int] = 'ACTIVE', paste_back: bool = False):
 
 
 def primitive_box(subdivision: int = 3,
-                  edges: int = 2,
+                  edges: int = 1,
                   type: typing.Union[str, int] = 'BOX',
                   wait_for_input: bool = True):
     ''' Create predefined grease pencil stroke box shapes
@@ -840,7 +842,7 @@ def primitive_box(subdivision: int = 3,
 
 
 def primitive_circle(subdivision: int = 94,
-                     edges: int = 2,
+                     edges: int = 1,
                      type: typing.Union[str, int] = 'CIRCLE',
                      wait_for_input: bool = True):
     ''' Create predefined grease pencil stroke circle shapes
@@ -859,7 +861,7 @@ def primitive_circle(subdivision: int = 94,
 
 
 def primitive_curve(subdivision: int = 62,
-                    edges: int = 2,
+                    edges: int = 1,
                     type: typing.Union[str, int] = 'CURVE',
                     wait_for_input: bool = True):
     ''' Create predefined grease pencil stroke curve shapes
@@ -878,7 +880,7 @@ def primitive_curve(subdivision: int = 62,
 
 
 def primitive_line(subdivision: int = 6,
-                   edges: int = 2,
+                   edges: int = 1,
                    type: typing.Union[str, int] = 'LINE',
                    wait_for_input: bool = True):
     ''' Create predefined grease pencil stroke lines
@@ -897,7 +899,7 @@ def primitive_line(subdivision: int = 6,
 
 
 def primitive_polyline(subdivision: int = 6,
-                       edges: int = 2,
+                       edges: int = 1,
                        type: typing.Union[str, int] = 'POLYLINE',
                        wait_for_input: bool = True):
     ''' Create predefined grease pencil stroke polylines
@@ -1446,7 +1448,7 @@ def stroke_normalize(mode: typing.Union[str, int] = 'THICKNESS',
 def stroke_reset_vertex_color(mode: typing.Union[str, int] = 'BOTH'):
     ''' Reset vertex color for all or selected strokes
 
-    :param mode: Mode * STROKE Stroke -- Reset Vertex Color to Stroke only. * FILL Fill -- Reset Vertex Color to Fill only. * BOTH Stroke and Fill -- Reset Vertex Color to Stroke and Fill.
+    :param mode: Mode * STROKE Stroke -- Reset Vertex Color to Stroke only. * FILL Fill -- Reset Vertex Color to Fill only. * BOTH Stroke & Fill -- Reset Vertex Color to Stroke and Fill.
     :type mode: typing.Union[str, int]
     '''
 
