@@ -1752,7 +1752,7 @@ def quads_convert_to_tris(quad_method: typing.Union[str, int] = 'BEAUTY',
                           ngon_method: typing.Union[str, int] = 'BEAUTY'):
     ''' Triangulate selected faces
 
-    :param quad_method: Quad Method, Method for splitting the quads into triangles * BEAUTY Beauty -- Split the quads in nice triangles, slower method. * FIXED Fixed -- Split the quads on the first and third vertices. * FIXED_ALTERNATE Fixed Alternate -- Split the quads on the 2nd and 4th vertices. * SHORTEST_DIAGONAL Shortest Diagonal -- Split the quads based on the distance between the vertices.
+    :param quad_method: Quad Method, Method for splitting the quads into triangles * BEAUTY Beauty -- Split the quads in nice triangles, slower method. * FIXED Fixed -- Split the quads on the first and third vertices. * FIXED_ALTERNATE Fixed Alternate -- Split the quads on the 2nd and 4th vertices. * SHORTEST_DIAGONAL Shortest Diagonal -- Split the quads along their shortest diagonal. * LONGEST_DIAGONAL Longest Diagonal -- Split the quads along their longest diagonal.
     :type quad_method: typing.Union[str, int]
     :param ngon_method: N-gon Method, Method for splitting the n-gons into triangles * BEAUTY Beauty -- Arrange the new triangles evenly (slow). * CLIP Clip -- Split the polygons with an ear clipping algorithm.
     :type ngon_method: typing.Union[str, int]
