@@ -44,6 +44,7 @@ def change_path(
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_usd: bool = False,
+        filter_obj: bool = False,
         filter_volume: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
@@ -88,6 +89,8 @@ def change_path(
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
@@ -235,6 +238,7 @@ def export_subtitles(filepath: str = "",
                      filter_collada: bool = False,
                      filter_alembic: bool = False,
                      filter_usd: bool = False,
+                     filter_obj: bool = False,
                      filter_volume: bool = False,
                      filter_folder: bool = True,
                      filter_blenlib: bool = False,
@@ -275,6 +279,8 @@ def export_subtitles(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
@@ -352,6 +358,7 @@ def image_strip_add(
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_usd: bool = False,
+        filter_obj: bool = False,
         filter_volume: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
@@ -401,6 +408,8 @@ def image_strip_add(
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
@@ -524,6 +533,7 @@ def movie_strip_add(
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_usd: bool = False,
+        filter_obj: bool = False,
         filter_volume: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
@@ -575,6 +585,8 @@ def movie_strip_add(
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
@@ -952,6 +964,7 @@ def sound_strip_add(
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_usd: bool = False,
+        filter_obj: bool = False,
         filter_volume: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
@@ -999,6 +1012,8 @@ def sound_strip_add(
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_obj: Filter OBJ files
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
     :type filter_volume: bool
     :param filter_folder: Filter folders
