@@ -1,11 +1,10 @@
 import sys
 import typing
 import bpy.types
+import bpy.context
 
-from . import units
 from . import previews
-
-GenericType = typing.TypeVar("GenericType")
+from . import units
 
 
 def app_template_paths(*, path: str = None):
@@ -21,7 +20,7 @@ def app_template_paths(*, path: str = None):
 
 def blend_paths(absolute: bool = False,
                 packed: bool = False,
-                local: bool = False) -> typing.List[str]:
+                local: bool = False) -> list:
     ''' Returns a list of paths to external files referenced by the loaded .blend file.
 
     :param absolute: When true the paths returned are made absolute.
@@ -30,7 +29,7 @@ def blend_paths(absolute: bool = False,
     :type packed: bool
     :param local: When true skip linked library paths.
     :type local: bool
-    :rtype: typing.List[str]
+    :rtype: list
     :return: path list.
     '''
 
@@ -61,6 +60,20 @@ def execfile(filepath: str, *, mod=None):
     pass
 
 
+def flip_name(name: str, strip_digits: bool = False) -> str:
+    ''' Flip a name between left/right sides, useful for mirroring bone names.
+
+    :param name: Bone name to flip.
+    :type name: str
+    :param strip_digits: Whether to remove .### suffix.
+    :type strip_digits: bool
+    :rtype: str
+    :return: The flipped name.
+    '''
+
+    pass
+
+
 def is_path_builtin(path):
     ''' 
 
@@ -99,8 +112,7 @@ def load_scripts(*,
     pass
 
 
-def make_rna_paths(struct_name: str, prop_name: str,
-                   enum_name: str) -> typing.Tuple:
+def make_rna_paths(struct_name: str, prop_name: str, enum_name: str) -> tuple:
     ''' Create RNA "paths" from given names.
 
     :param struct_name: Name of a RNA struct (like e.g. "Scene").
@@ -109,7 +121,7 @@ def make_rna_paths(struct_name: str, prop_name: str,
     :type prop_name: str
     :param enum_name: Name of a RNA enum identifier.
     :type enum_name: str
-    :rtype: typing.Tuple
+    :rtype: tuple
     :return: A triple of three "RNA paths" (most_complete_path, "struct.prop", "struct.prop:'enum'"). If no enum_name is given, the third element will always be void.
     '''
 
@@ -124,14 +136,14 @@ def manual_map():
     pass
 
 
-def modules_from_path(path: str, loaded_modules: typing.Set) -> typing.List:
+def modules_from_path(path: str, loaded_modules: set) -> list:
     ''' Load all modules in a path and return them as a list.
 
     :param path: this path is scanned for scripts and packages.
     :type path: str
     :param loaded_modules: already loaded module names, files matching these names will be ignored.
-    :type loaded_modules: typing.Set
-    :rtype: typing.List
+    :type loaded_modules: set
+    :rtype: list
     :return: all loaded modules.
     '''
 
@@ -146,12 +158,12 @@ def preset_find(name, preset_path, *, display_name=False, ext='.py'):
     pass
 
 
-def preset_paths(subdir: str) -> typing.List:
+def preset_paths(subdir: str) -> list:
     ''' Returns a list of paths for a specific preset.
 
     :param subdir: preset subdirectory (must not be an absolute path).
     :type subdir: str
-    :rtype: typing.List
+    :rtype: list
     :return: script paths.
     '''
 
@@ -191,15 +203,15 @@ def register_manual_map(manual_hook):
     pass
 
 
-def register_submodule_factory(
-        module_name: str, submodule_names: typing.List[str]) -> typing.Tuple:
+def register_submodule_factory(module_name: str,
+                               submodule_names: list) -> tuple:
     ''' Utility function to create register and unregister functions which simply load submodules, calling their register & unregister functions.
 
     :param module_name: The module name, typically __name__ .
     :type module_name: str
     :param submodule_names: List of submodule names to load and unload.
-    :type submodule_names: typing.List[str]
-    :rtype: typing.Tuple
+    :type submodule_names: list
+    :rtype: tuple
     :return: register and unregister functions.
     '''
 
@@ -208,7 +220,7 @@ def register_submodule_factory(
 
 def register_tool(tool_cls,
                   *,
-                  after=None,
+                  after: 'bpy.context.collection' = None,
                   separator: bool = False,
                   group: bool = False):
     ''' Register a tool in the toolbar.
@@ -218,6 +230,7 @@ def register_tool(tool_cls,
     :param space_type: Space type identifier.
     :type space_type: str
     :param after: Optional identifiers this tool will be added after.
+    :type after: 'bpy.context.collection'
     :param separator: When true, add a separator before this tool.
     :type separator: bool
     :param group: When true, add a new nested group of tools.
@@ -265,7 +278,7 @@ def script_paths(*,
                  subdir: str = None,
                  user_pref: bool = True,
                  check_all: bool = False,
-                 use_user=True) -> typing.List:
+                 use_user=True) -> list:
     ''' Returns a list of valid script paths.
 
     :param subdir: Optional subdir.
@@ -274,7 +287,7 @@ def script_paths(*,
     :type user_pref: bool
     :param check_all: Include local, user and system paths rather just the paths blender uses.
     :type check_all: bool
-    :rtype: typing.List
+    :rtype: list
     :return: script paths.
     '''
 
@@ -293,11 +306,14 @@ def smpte_from_frame(frame: int, *, fps=None, fps_base=None) -> str:
     pass
 
 
-def smpte_from_seconds(time: int, *, fps=None, fps_base=None) -> str:
+def smpte_from_seconds(time: typing.Union[int, float],
+                       *,
+                       fps=None,
+                       fps_base=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: HH:MM:SS:FF . If *fps* and *fps_base* are not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: int
+    :type time: typing.Union[int, float]
     :rtype: str
     :return: the frame string.
     '''
