@@ -1,9 +1,6 @@
 import sys
 import typing
 import bpy.types
-import aud
-
-GenericType = typing.TypeVar("GenericType")
 
 
 def bake_action(obj: 'bpy.types.Object', *, action: 'bpy.types.Action',
@@ -73,11 +70,14 @@ def bake_action_objects(object_action_pairs, *, frames: int,
     pass
 
 
-def bake_action_objects_iter(object_action_pairs: 'aud.Sequence', **kwargs):
+def bake_action_objects_iter(
+        object_action_pairs: typing.
+        Union['bpy.types.Sequence', 'bpy.types.Object', 'bpy.types.Action'],
+        **kwargs):
     ''' An coroutine that bakes actions for multiple objects.
 
     :param object_action_pairs: Sequence of object action tuples, action is the destination for the baked data. When None a new action will be created.
-    :type object_action_pairs: 'aud.Sequence'
+    :type object_action_pairs: typing.Union['bpy.types.Sequence', 'bpy.types.Object', 'bpy.types.Action']
     '''
 
     pass
