@@ -4,8 +4,6 @@ import freestyle.types
 import bpy.types
 import mathutils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class BackboneStretcherShader:
     ''' Class hierarchy: freestyle.types.StrokeShader > BackboneStretcherShader [Geometry shader]
@@ -53,11 +51,12 @@ class BlenderTextureShader:
     ''' Class hierarchy: freestyle.types.StrokeShader > BlenderTextureShader [Texture shader]
     '''
 
-    def __init__(self, texture: 'bpy.types.LineStyleTextureSlot'):
+    def __init__(self, texture: typing.Union['bpy.types.LineStyleTextureSlot',
+                                             'bpy.types.ShaderNodeTree']):
         ''' Builds a BlenderTextureShader object.
 
         :param texture: A line style texture slot or a shader node tree to define a set of textures.
-        :type texture: 'bpy.types.LineStyleTextureSlot'
+        :type texture: typing.Union['bpy.types.LineStyleTextureSlot', 'bpy.types.ShaderNodeTree']
         '''
         pass
 
