@@ -1,9 +1,8 @@
 import sys
 import typing
+import bpy.types
 import mathutils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class AdjacencyIterator:
     ''' Class hierarchy: Iterator > AdjacencyIterator Class for representing adjacency iterators used in the chaining process. An AdjacencyIterator is created in the increment() and decrement() methods of a ChainingIterator and passed to the traverse() method of the ChainingIterator.
@@ -219,25 +218,25 @@ class Curve:
         ''' __init__(brother) __init__(id) Builds a FrsCurve using a default constructor, copy constructor or from an Id .
 
         :param brother: A Curve object.
-        :type brother: 'Curve'
+        :type brother: 'bpy.types.Curve'
         :param id: An Id object.
         :type id: 'Id'
         '''
         pass
 
-    def push_vertex_back(self, vertex: 'SVertex'):
+    def push_vertex_back(self, vertex: typing.Union['CurvePoint', 'SVertex']):
         ''' Adds a single vertex at the end of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: 'SVertex'
+        :type vertex: typing.Union['CurvePoint', 'SVertex']
         '''
         pass
 
-    def push_vertex_front(self, vertex: 'SVertex'):
+    def push_vertex_front(self, vertex: typing.Union['CurvePoint', 'SVertex']):
         ''' Adds a single vertex at the front of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: 'SVertex'
+        :type vertex: typing.Union['CurvePoint', 'SVertex']
         '''
         pass
 
@@ -415,16 +414,16 @@ class FEdgeSharp:
     :type: int
     '''
 
-    material_left: 'Material' = None
+    material_left: 'bpy.types.Material' = None
     ''' The material of the face lying on the left of the FEdge.
 
-    :type: 'Material'
+    :type: 'bpy.types.Material'
     '''
 
-    material_right: 'Material' = None
+    material_right: 'bpy.types.Material' = None
     ''' The material of the face lying on the right of the FEdge. If this FEdge is a border, it has no Face on its right and therefore no material.
 
-    :type: 'Material'
+    :type: 'bpy.types.Material'
     '''
 
     normal_left: 'mathutils.Vector' = None
@@ -462,10 +461,10 @@ class FEdgeSmooth:
     :type: bool
     '''
 
-    material: 'Material' = None
+    material: 'bpy.types.Material' = None
     ''' The material of the face that this FEdge is running across.
 
-    :type: 'Material'
+    :type: 'bpy.types.Material'
     '''
 
     material_index: int = None
@@ -632,7 +631,7 @@ class Interface0DIterator:
         :param brother: An Interface0DIterator object.
         :type brother: 'Interface0DIterator'
         :param it: An iterator object to be nested.
-        :type it: 'SVertexIterator'
+        :type it: typing.Union['CurvePointIterator', 'SVertexIterator', 'StrokeVertexIterator']
         '''
         pass
 
@@ -805,17 +804,17 @@ class Material:
         ''' __init__(brother) __init__(line, diffuse, ambient, specular, emission, shininess, priority) Creates a FrsMaterial using either default constructor, copy constructor, or an overloaded constructor
 
         :param brother: A Material object to be used as a copy constructor.
-        :type brother: 'Material'
+        :type brother: 'bpy.types.Material'
         :param line: The line color.
-        :type line: 'mathutils.Vector'
+        :type line: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param diffuse: The diffuse color.
-        :type diffuse: 'mathutils.Vector'
+        :type diffuse: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param ambient: The ambient color.
-        :type ambient: 'mathutils.Vector'
+        :type ambient: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param specular: The specular color.
-        :type specular: 'mathutils.Vector'
+        :type specular: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param emission: The emissive color.
-        :type emission: 'mathutils.Vector'
+        :type emission: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param shininess: The shininess coefficient.
         :type shininess: float
         :param priority: The line color priority.
@@ -860,21 +859,21 @@ class Noise:
         '''
         pass
 
-    def smoothNoise2(self, v: 'mathutils.Vector') -> float:
+    def smoothNoise2(self, v: typing.List['mathutils.Vector']) -> float:
         ''' Returns a smooth noise value for a 2D element.
 
         :param v: Two-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :rtype: float
         :return: A smooth noise value.
         '''
         pass
 
-    def smoothNoise3(self, v: 'mathutils.Vector') -> float:
+    def smoothNoise3(self, v: typing.List['mathutils.Vector']) -> float:
         ''' Returns a smooth noise value for a 3D element.
 
         :param v: Three-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :rtype: float
         :return: A smooth noise value.
         '''
@@ -898,14 +897,14 @@ class Noise:
         pass
 
     def turbulence2(self,
-                    v: 'mathutils.Vector',
+                    v: typing.List['mathutils.Vector'],
                     freq: float,
                     amp: float,
                     oct: int = 4) -> float:
         ''' Returns a noise value for a 2D element.
 
         :param v: Two-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :param freq: Noise frequency.
         :type freq: float
         :param amp: Amplitude.
@@ -918,14 +917,14 @@ class Noise:
         pass
 
     def turbulence3(self,
-                    v: 'mathutils.Vector',
+                    v: typing.List['mathutils.Vector'],
                     freq: float,
                     amp: float,
                     oct: int = 4) -> float:
         ''' Returns a noise value for a 3D element.
 
         :param v: Three-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :param freq: Noise frequency.
         :type freq: float
         :param amp: Amplitude.
@@ -962,14 +961,13 @@ class Operators:
     '''
 
     @staticmethod
-    def bidirectional_chain(it: 'ChainingIterator',
-                            pred: typing.Optional['UnaryPredicate1D']):
+    def bidirectional_chain(it: 'ChainingIterator', pred: 'UnaryPredicate1D'):
         ''' bidirectional_chain(it) Builds a set of chains from the current set of ViewEdges. Each ViewEdge of the current list potentially starts a new chain. The chaining operator then iterates over the ViewEdges of the ViewMap using the user specified iterator. This operator iterates both using the increment and decrement operators and is therefore bidirectional. This operator works with a ChainingIterator which contains the chaining rules. It is this last one which can be told to chain only edges that belong to the selection or not to process twice a ViewEdge during the chaining. Each time a ViewEdge is added to a chain, its chaining time stamp is incremented. This allows you to keep track of the number of chains to which a ViewEdge belongs to.
 
         :param it: The ChainingIterator on the ViewEdges of the ViewMap. It contains the chaining rule.
         :type it: 'ChainingIterator'
         :param pred: The predicate on the ViewEdge that expresses the stopping condition. This parameter is optional, you make not want to pass a stopping criterion when the stopping criterion is already contained in the iterator definition.
-        :type pred: typing.Optional['UnaryPredicate1D']
+        :type pred: 'UnaryPredicate1D'
         '''
         pass
 
@@ -1189,10 +1187,10 @@ class SVertex:
     ''' Class hierarchy: Interface0D > SVertex Class to define a vertex of the embedding.
     '''
 
-    curvatures: typing.Tuple = None
+    curvatures: tuple = None
     ''' Curvature information expressed in the form of a seven-element tuple (K1, e1, K2, e2, Kr, er, dKr), where K1 and K2 are scalar values representing the first (maximum) and second (minimum) principal curvatures at this SVertex, respectively; e1 and e2 are three-dimensional vectors representing the first and second principal directions, i.e. the directions of the normal plane where the curvature takes its maximum and minimum values, respectively; and Kr, er and dKr are the radial curvature, radial direction, and the derivative of the radial curvature at this SVertex, respectively.
 
-    :type: typing.Tuple
+    :type: tuple
     '''
 
     id: 'Id' = None
@@ -1251,11 +1249,11 @@ class SVertex:
         '''
         pass
 
-    def add_normal(self, normal: 'mathutils.Vector'):
+    def add_normal(self, normal: typing.List['mathutils.Vector']):
         ''' Adds a normal to the SVertex's set of normals. If the same normal is already in the set, nothing changes.
 
         :param normal: A three-dimensional vector.
-        :type normal: 'mathutils.Vector'
+        :type normal: typing.List['mathutils.Vector']
         '''
         pass
 
@@ -1543,23 +1541,25 @@ class StrokeAttribute:
         '''
         pass
 
-    def set_attribute_vec2(self, name: str, value: 'mathutils.Vector'):
+    def set_attribute_vec2(self, name: str,
+                           value: typing.List['mathutils.Vector']):
         ''' Adds a user-defined attribute of two-dimensional vector type. If there is no attribute of the given name, it is added. Otherwise, the new value replaces the old one.
 
         :param name: The name of the attribute.
         :type name: str
         :param value: The attribute value.
-        :type value: 'mathutils.Vector'
+        :type value: typing.List['mathutils.Vector']
         '''
         pass
 
-    def set_attribute_vec3(self, name: str, value: 'mathutils.Vector'):
+    def set_attribute_vec3(self, name: str,
+                           value: typing.List['mathutils.Vector']):
         ''' Adds a user-defined attribute of three-dimensional vector type. If there is no attribute of the given name, it is added. Otherwise, the new value replaces the old one.
 
         :param name: The name of the attribute.
         :type name: str
         :param value: The attribute value.
-        :type value: 'mathutils.Vector'
+        :type value: typing.List['mathutils.Vector']
         '''
         pass
 
@@ -2283,10 +2283,10 @@ class ViewShape:
     :type: 'Id'
     '''
 
-    library_path: str = None
+    library_path: typing.Union[str, 'ViewShape'] = None
     ''' The library path of the ViewShape.
 
-    :type: str
+    :type: typing.Union[str, 'ViewShape']
     '''
 
     name: str = None
