@@ -2,13 +2,11 @@ import sys
 import typing
 import freestyle.types
 
-GenericType = typing.TypeVar("GenericType")
 
-
-def get_border() -> typing.Tuple:
+def get_border() -> tuple:
     ''' Returns the border.
 
-    :rtype: typing.Tuple
+    :rtype: tuple
     :return: A tuple of 4 numbers (xmin, ymin, xmax, ymax).
     '''
 
