@@ -1,16 +1,6 @@
 import sys
 import typing
 
-GenericType = typing.TypeVar("GenericType")
-
-
-def blend_depth_test_get():
-    ''' Current depth_test equation.
-
-    '''
-
-    pass
-
 
 def blend_get():
     ''' Current blending equation.
@@ -23,7 +13,7 @@ def blend_get():
 def blend_set(mode: str):
     ''' Defines the fixed pipeline blending equation.
 
-    :param mode: The type of blend mode. * ``NONE`` No blending. * ``ALPHA`` The original color channels are interpolated according to the alpha value. * ``ALPHA_PREMULT`` The original color channels are interpolated according to the alpha value with the new colors pre-multiplied by this value. * ``ADDITIVE`` The original color channels are added by the corresponding ones. * ``ADDITIVE_PREMULT`` The original color channels are added by the corresponding ones that are pre-multiplied by the alpha value. * ``MULTIPLY`` The original color channels are multiplied by the corresponding ones. * ``SUBTRACT`` The original color channels are subtracted by the corresponding ones. * ``INVERT`` The original color channels are replaced by its complementary color.
+    :param mode: The type of blend mode. * NONE No blending. * ALPHA The original color channels are interpolated according to the alpha value. * ALPHA_PREMULT The original color channels are interpolated according to the alpha value with the new colors pre-multiplied by this value. * ADDITIVE The original color channels are added by the corresponding ones. * ADDITIVE_PREMULT The original color channels are added by the corresponding ones that are pre-multiplied by the alpha value. * MULTIPLY The original color channels are multiplied by the corresponding ones. * SUBTRACT The original color channels are subtracted by the corresponding ones. * INVERT The original color channels are replaced by its complementary color.
     :type mode: str
     '''
 
@@ -31,7 +21,7 @@ def blend_set(mode: str):
 
 
 def clip_distances_set(distances_enabled: int):
-    ''' Sets the number of `gl_ClipDistance` planes used for clip geometry.
+    ''' Sets the number of gl_ClipDistance planes used for clip geometry.
 
     :param distances_enabled: Number of clip distances enabled.
     :type distances_enabled: int
@@ -56,19 +46,25 @@ def color_mask_set(r: bool, g: bool, b: bool, a: bool):
     pass
 
 
-def depth_mask_set(value: typing.Any):
-    ''' Write to depth component.
+def depth_mask_get():
+    ''' Writing status in the depth component.
 
-    :type near: bool
-    :param value:  True for writing to the depth component.
-    :type value: typing.Any
     '''
 
     pass
 
 
-def depth_mask_set_get():
-    ''' Writing status in the depth component.
+def depth_mask_set(value):
+    ''' Write to depth component.
+
+    :type near: bool
+    '''
+
+    pass
+
+
+def depth_test_get():
+    ''' Current depth_test equation.
 
     '''
 
@@ -78,7 +74,7 @@ def depth_mask_set_get():
 def depth_test_set(mode: str):
     ''' Defines the depth_test equation.
 
-    :param mode: The depth test equation name. Possible values are `NONE`, `ALWAYS`, `LESS`, `LESS_EQUAL`, `EQUAL`, `GREATER` and `GREATER_EQUAL`.
+    :param mode: The depth test equation name. Possible values are NONE , ALWAYS , LESS , LESS_EQUAL , EQUAL , GREATER and GREATER_EQUAL .
     :type mode: str
     '''
 
@@ -88,7 +84,7 @@ def depth_test_set(mode: str):
 def face_culling_set(culling):
     ''' Specify whether none, front-facing or back-facing facets can be culled.
 
-    :param mode: `NONE`, `FRONT` or `BACK`.
+    :param mode: NONE , FRONT or BACK .
     :type mode: str
     '''
 
@@ -103,12 +99,10 @@ def framebuffer_active_get(enable):
     pass
 
 
-def front_facing_set(invert: typing.Any):
+def front_facing_set(invert):
     ''' Specifies the orientation of front-facing polygons.
 
     :type mode: bool
-    :param invert:  True for clockwise polygons as front-facing.
-    :type invert: typing.Any
     '''
 
     pass
@@ -126,25 +120,21 @@ def line_width_set(width):
     ''' Specify the width of rasterized lines.
 
     :type mode: float
-    :param size:  New width.
-    :type size: typing.Any
     '''
 
     pass
 
 
-def point_size_set(size: typing.Any):
+def point_size_set(size):
     ''' Specify the diameter of rasterized points.
 
     :type mode: float
-    :param size:  New diameter.
-    :type size: typing.Any
     '''
 
     pass
 
 
-def use_program_point_size(enable: bool):
+def program_point_size_set(enable: bool):
     ''' If enabled, the derived point size is taken from the (potentially clipped) shader builtin gl_PointSize.
 
     :param enable: True for shader builtin gl_PointSize.
@@ -171,10 +161,6 @@ def viewport_set(x: int, y: int, xsize: int, ysize: int):
     :type y: int
     :type xsize: int
     :type ysize: int
-    :param width:  width and height of the viewport_set.
-    :type width: typing.Any
-    :param height:  width and height of the viewport_set.
-    :type height: typing.Any
     '''
 
     pass
