@@ -2,8 +2,6 @@ import sys
 import typing
 import nodeitems_utils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class SortedNodeCategory(nodeitems_utils.NodeCategory):
     def poll(self, _context):
@@ -117,7 +115,7 @@ def group_input_output_item_poll(context):
     pass
 
 
-def group_tools_draw(layout, _context):
+def group_tools_draw(_self, layout, _context):
     ''' 
 
     '''
